@@ -1,10 +1,12 @@
-from .gp import *
+from .model import *
 from .krige import *
 from .mesh import *
-from .covfunc import Observation
+from .gp import Observation
+
+__version__ = '0.6.1'
 
 __all__ = []
-__all__.extend(gp.__all__)
+__all__.extend(model.__all__)
 __all__.extend(krige.__all__)
 __all__.extend(mesh.__all__)
 __all__.extend('Observation')
